@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -202,9 +202,9 @@ public:
 
     this->m_IsAtEnd = true;
     // Initialize the temporary image
-    m_TemporaryPointer->FillBuffer(NumericTraits<typename TTempImage::PixelType>::ZeroValue());
+    m_TemporaryPointer->FillBuffer(typename TTempImage::PixelType{});
 
-    for (unsigned int i = 0; i < m_Seeds.size(); i++)
+    for (unsigned int i = 0; i < m_Seeds.size(); ++i)
     {
       if (this->m_Image->GetBufferedRegion().IsInside(m_Seeds[i]) && this->IsPixelIncluded(m_Seeds[i]))
       {
@@ -239,7 +239,7 @@ public:
 
 protected: // made protected so other iterators can access
   /** Smart pointer to the function we're evaluating */
-  SmartPointer<FunctionType> m_Function;
+  SmartPointer<FunctionType> m_Function{};
 
   /** A temporary image used for storing info about indices
    * 0 = pixel has not yet been processed
@@ -247,32 +247,32 @@ protected: // made protected so other iterators can access
    * 2 = pixel is inside the function, neighbor check incomplete
    * 3 = pixel is inside the function, neighbor check complete */
   using TTempImage = Image<unsigned char, Self::NDimensions>;
-  typename TTempImage::Pointer m_TemporaryPointer;
+  typename TTempImage::Pointer m_TemporaryPointer{};
 
   /** A list of locations to start the recursive fill */
-  SeedsContainerType m_Seeds;
+  SeedsContainerType m_Seeds{};
 
   /** The origin of the source image */
-  typename ImageType::PointType m_ImageOrigin;
+  typename ImageType::PointType m_ImageOrigin{};
 
   /** The spacing of the source image */
-  typename ImageType::SpacingType m_ImageSpacing;
+  typename ImageType::SpacingType m_ImageSpacing{};
 
   /** Region of the source image */
-  RegionType m_ImageRegion;
+  RegionType m_ImageRegion{};
 
   /** Stack used to hold the path of the iterator through the image */
-  std::queue<IndexType> m_IndexStack;
+  std::queue<IndexType> m_IndexStack{};
 
   /** Location vector used in the flood algorithm */
-  FunctionInputType m_LocationVector;
+  FunctionInputType m_LocationVector{};
 
   /** Indicates whether or not we've found a neighbor that needs to be
    * checked.  */
-  bool m_FoundUncheckedNeighbor;
+  bool m_FoundUncheckedNeighbor{};
 
   /** Indicates whether or not an index is valid (inside an image)/ */
-  bool m_IsValidIndex;
+  bool m_IsValidIndex{};
 };
 } // end namespace itk
 
