@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -93,8 +93,8 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
-  /** Standard part of every itk Object. */
-  itkTypeMacro(PointSet, Object);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(PointSet);
 
   /** Hold on to the type information specified by the template parameters. */
   using MeshTraits = TMeshTraits;
@@ -107,6 +107,10 @@ public:
   using PointsContainer = typename MeshTraits::PointsContainer;
   using PointDataContainer = typename MeshTraits::PointDataContainer;
 
+  /** For improving Python support for PointSet and Meshes **/
+  using PointsVectorContainer = typename itk::VectorContainer<PointIdentifier, CoordRepType>;
+  using PointsVectorContainerPointer = typename PointsVectorContainer::Pointer;
+
   /** Convenient type alias obtained from TMeshTraits template parameter. */
   static constexpr unsigned int PointDimension = TMeshTraits::PointDimension;
 
@@ -131,56 +135,88 @@ public:
 protected:
   /** An object containing points used by the mesh.  Individual points are
    * accessed through point identifiers. */
-  PointsContainerPointer m_PointsContainer;
+  PointsContainerPointer m_PointsContainer{};
 
   /** An object containing data associated with the mesh's points.
    * Optionally, this can be nullptr, indicating that no data are associated with
    * the points.  The data for a point can be accessed through its point
    * identifier. */
-  PointDataContainerPointer m_PointDataContainer;
+  PointDataContainerPointer m_PointDataContainer{};
 
 public:
-  /** PointSet-level operation interface. */
+  /** Copy the geometric and topological structure of the given input pointSet.
+   * The copying is done via reference counting.
+   */
   void
   PassStructure(Self * inputPointSet);
 
+  /** Restore the PointSet to its initial state. Useful for data pipeline updates
+   * without memory re-allocation.
+   */
   void
   Initialize() override;
 
+  /** Get the number of points in the points container. */
   PointIdentifier
   GetNumberOfPoints() const;
 
-  /** Define Set/Get access routines for each internal container.
-   * Methods also exist to add points, cells, etc. one at a time
-   * rather than through an entire container. */
+  /** Set the points container. */
   void
   SetPoints(PointsContainer *);
 
+  /** Set the points container using a 1D vector. */
+  void
+  SetPoints(PointsVectorContainer *);
+
+  /** Get the points container. */
   PointsContainer *
   GetPoints();
 
+  /** Get the points container. */
   const PointsContainer *
   GetPoints() const;
 
+  /** Set the point data container. */
   void
   SetPointData(PointDataContainer *);
 
+  /** Get the point data container. */
   PointDataContainer *
   GetPointData();
 
+  /** Get the point data container. */
   const PointDataContainer *
   GetPointData() const;
 
-  /** Access routines to fill the Points container, and get information
-   * from it. */
+  /** Assign a point to a point identifier.  If a spot for the point identifier
+   * does not exist, it will be created automatically.
+   */
   void SetPoint(PointIdentifier, PointType);
+
+  /** Check if a point exists for a given point identifier.  If a spot for
+   * the point identifier exists, the point is set, and true is returned.
+   * Otherwise, false is returned, and the point is not modified.
+   * If the point is nullptr, then it is never set, but the existence of the
+   * point is still returned.
+   */
   bool
-            GetPoint(PointIdentifier, PointType *) const;
+  GetPoint(PointIdentifier, PointType *) const;
+
+  /** Get the point for the given point identifier. */
   PointType GetPoint(PointIdentifier) const;
 
-  /** Access routines to fill the PointData container, and get information
-   * from it. */
+  /** Assign data to a point identifier.  If a spot for the point identifier
+   * does not exist, it will be created automatically.  There is no check if
+   * a point with the same identifier exists.
+   */
   void SetPointData(PointIdentifier, PixelType);
+
+  /** Check if point data exists for a given point identifier.  If a spot for
+   * the point identifier exists, "data" is set, and true is returned.
+   * Otherwise, false is returned, and "data" is not modified.
+   * If "data" is nullptr, then it is never set, but the existence of the point
+   * data is still returned.
+   */
   bool
   GetPointData(PointIdentifier, PixelType *) const;
 
@@ -224,7 +260,7 @@ public:
 
 protected:
   /** Constructor for use by New() method. */
-  PointSet();
+  PointSet() = default;
   ~PointSet() override = default;
   void
   PrintSelf(std::ostream & os, Indent indent) const override;
@@ -239,11 +275,11 @@ protected:
   // RequestedRegion are used to define the currently requested
   // region. The LargestPossibleRegion is always requested region = 0
   // and number of regions = 1;
-  RegionType m_MaximumNumberOfRegions;
-  RegionType m_NumberOfRegions;
-  RegionType m_RequestedNumberOfRegions;
-  RegionType m_BufferedRegion;
-  RegionType m_RequestedRegion;
+  RegionType m_MaximumNumberOfRegions{ 1 };
+  RegionType m_NumberOfRegions{ 1 };
+  RegionType m_RequestedNumberOfRegions{};
+  RegionType m_BufferedRegion{ -1 };
+  RegionType m_RequestedRegion{ -1 };
 }; // End Class: PointSet
 } // end namespace itk
 
@@ -251,10 +287,4 @@ protected:
 #  include "itkPointSet.hxx"
 #endif
 
-/*
-#ifndef ITK_MANUAL_INSTANTIATION
-#include "itkPointSet.hxx"
-#endif
-*/
-
 #endif
