@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -82,7 +82,7 @@ itkRealTimeClockTest(int, char *[])
       std::cout << realStamp2 << " - " << realStamp1 << " = ";
       std::cout << secondsD << " = " << secondsE << std::endl;
 
-      if (std::abs(secondsD - secondsE) / secondsE > tolerance)
+      if (itk::Math::abs(secondsD - secondsE) / secondsE > tolerance)
       {
         std::cerr << "Precision error in time difference" << std::endl;
         std::cerr << "Expected " << secondsE << " seconds " << std::endl;
