@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -46,24 +46,22 @@ itkSparseImageTest(int, char *[])
   using SparseImageType = itk::SparseImage<NodeType, 2>;
   using ImageType = SparseImageType::Superclass;
 
-  SparseImageType::Pointer im = SparseImageType::New();
-  ImageType::RegionType    r;
-  ImageType::SizeType      sz = { { 24, 24 } };
-  ImageType::IndexType     idx = { { 0, 0 } };
+  auto                  im = SparseImageType::New();
+  ImageType::RegionType r;
+  ImageType::SizeType   sz = { { 24, 24 } };
+  ImageType::IndexType  idx = { { 0, 0 } };
   r.SetSize(sz);
   r.SetIndex(idx);
 
-  im->SetLargestPossibleRegion(r);
-  im->SetBufferedRegion(r);
-  im->SetRequestedRegion(r);
+  im->SetRegions(r);
   im->Allocate();
 
   ImageType::IndexType index;
   NodeType *           node;
   int                  cnt = 0;
 
-  for (index[0] = 0; index[0] < 24; index[0]++)
-    for (index[1] = 0; index[1] < 24; index[1]++)
+  for (index[0] = 0; index[0] < 24; ++index[0])
+    for (index[1] = 0; index[1] < 24; ++index[1])
     {
       if ((index[0] >= 6) && (index[0] <= 12) && (index[1] >= 6) && (index[1] <= 12))
       {
