@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -26,7 +26,7 @@ namespace itk
 namespace Accessor
 {
 /**
- *\class ComplexToPhasePixelAccessor
+ * \class ComplexToPhasePixelAccessor
  * \brief Give access to the Phase part of a std::complex<> value.
  *
  * ComplexToPhasePixelAccessor is templated over an internal type and an
@@ -65,7 +65,7 @@ public:
 } // end namespace Accessor
 
 /**
- *\class ComplexToPhaseImageAdaptor
+ * \class ComplexToPhaseImageAdaptor
  * \brief Presents a complex image as being composed of arg() part of its pixels.
  *
  * Additional casting is performed according to the input and output image
@@ -91,8 +91,8 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
-  /** Run-time type information (and related methods). */
-  itkTypeMacro(ComplexToPhaseImageAdaptor, ImageAdaptor);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(ComplexToPhaseImageAdaptor);
 
 protected:
   ComplexToPhaseImageAdaptor() = default;
