@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -64,8 +64,8 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
-  /** Run-time type information (and related methods). */
-  itkTypeMacro(TransformMeshFilter, MeshToMeshFilter);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(TransformMeshFilter);
 
   /** Get/Set transform. */
   itkSetObjectMacro(Transform, TransformType);
@@ -82,7 +82,7 @@ protected:
   GenerateData() override;
 
   /** Transform to apply to all the mesh points. */
-  typename TransformType::Pointer m_Transform;
+  typename TransformType::Pointer m_Transform{};
 };
 } // end namespace itk
 
