@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,40 +21,40 @@
 #include "itkMapContainer.h"
 
 // -------------------------------------------------------------------------
-#define itkQEDefineFrontIteratorMethodsMacro(MeshTypeArg)                                                              \
-  /* Dual definition placed before others because of .NET that cannot */                                               \
-  /* cope with definition of FrontIterator (that further hides the    */                                               \
-  /* definition of the template).                                     */                                               \
-  using QEDualType = typename MeshTypeArg::QEDual;                                                                     \
-  using QEPrimalType = typename MeshTypeArg::QEPrimal;                                                                 \
-  using FrontDualIterator = QuadEdgeMeshFrontIterator<MeshTypeArg, QEDualType>;                                        \
-  using ConstFrontDualIterator = QuadEdgeMeshConstFrontIterator<MeshTypeArg, QEDualType>;                              \
-  using FrontIterator = QuadEdgeMeshFrontIterator<MeshTypeArg, QEPrimalType>;                                          \
-  using ConstFrontIterator = QuadEdgeMeshConstFrontIterator<MeshTypeArg, QEPrimalType>;                                \
-                                                                                                                       \
-  virtual FrontIterator BeginFront(QEPrimalType * seed = (QEPrimalType *)0)                                            \
-  {                                                                                                                    \
-    return (FrontIterator(this, true, seed));                                                                          \
-  }                                                                                                                    \
-                                                                                                                       \
-  virtual ConstFrontIterator BeginFront(QEPrimalType * seed) const { return (ConstFrontIterator(this, true, seed)); }  \
-                                                                                                                       \
-  virtual FrontIterator EndFront() { return (FrontIterator(this, false)); }                                            \
-                                                                                                                       \
-  virtual ConstFrontIterator EndFront() const { return (ConstFrontIterator(this, false)); }                            \
-                                                                                                                       \
-  virtual FrontDualIterator BeginDualFront(QEDualType * seed = (QEDualType *)0)                                        \
-  {                                                                                                                    \
-    return (FrontDualIterator(this, true, seed));                                                                      \
-  }                                                                                                                    \
-                                                                                                                       \
-  virtual ConstFrontDualIterator BeginDualFront(QEDualType * seed) const                                               \
-  {                                                                                                                    \
-    return (ConstFrontDualIterator(this, true, seed));                                                                 \
-  }                                                                                                                    \
-                                                                                                                       \
-  virtual FrontDualIterator EndDualFront() { return (FrontDualIterator(this, false)); }                                \
-                                                                                                                       \
+#define itkQEDefineFrontIteratorMethodsMacro(MeshTypeArg)                                                             \
+  /* Dual definition placed before others because of .NET that cannot */                                              \
+  /* cope with definition of FrontIterator (that further hides the    */                                              \
+  /* definition of the template).                                     */                                              \
+  using QEDualType = typename MeshTypeArg::QEDual;                                                                    \
+  using QEPrimalType = typename MeshTypeArg::QEPrimal;                                                                \
+  using FrontDualIterator = QuadEdgeMeshFrontIterator<MeshTypeArg, QEDualType>;                                       \
+  using ConstFrontDualIterator = QuadEdgeMeshConstFrontIterator<MeshTypeArg, QEDualType>;                             \
+  using FrontIterator = QuadEdgeMeshFrontIterator<MeshTypeArg, QEPrimalType>;                                         \
+  using ConstFrontIterator = QuadEdgeMeshConstFrontIterator<MeshTypeArg, QEPrimalType>;                               \
+                                                                                                                      \
+  virtual FrontIterator BeginFront(QEPrimalType * seed = (QEPrimalType *)0)                                           \
+  {                                                                                                                   \
+    return (FrontIterator(this, true, seed));                                                                         \
+  }                                                                                                                   \
+                                                                                                                      \
+  virtual ConstFrontIterator BeginFront(QEPrimalType * seed) const { return (ConstFrontIterator(this, true, seed)); } \
+                                                                                                                      \
+  virtual FrontIterator EndFront() { return (FrontIterator(this, false)); }                                           \
+                                                                                                                      \
+  virtual ConstFrontIterator EndFront() const { return (ConstFrontIterator(this, false)); }                           \
+                                                                                                                      \
+  virtual FrontDualIterator BeginDualFront(QEDualType * seed = (QEDualType *)0)                                       \
+  {                                                                                                                   \
+    return (FrontDualIterator(this, true, seed));                                                                     \
+  }                                                                                                                   \
+                                                                                                                      \
+  virtual ConstFrontDualIterator BeginDualFront(QEDualType * seed) const                                              \
+  {                                                                                                                   \
+    return (ConstFrontDualIterator(this, true, seed));                                                                \
+  }                                                                                                                   \
+                                                                                                                      \
+  virtual FrontDualIterator EndDualFront() { return (FrontDualIterator(this, false)); }                               \
+                                                                                                                      \
   virtual ConstFrontDualIterator EndDualFront() const { return (ConstFrontDualIterator(this, false)); }
 
 namespace itk
@@ -68,7 +68,7 @@ namespace itk
  * Unlike them, this iterator is not local, nor cyclic. Starting from a
  * given seed, it will create a front that propagates on the surface.
  * Depending on the weight associated which each edge, and on the type of the
- * seed (primal or dual) it can be used for frint propagation algorithm,
+ * seed (primal or dual) it can be used for front propagation algorithm,
  * distance tree computation or other Djikstra like algorithms.
  * \ingroup ITKQuadEdgeMesh
  */
@@ -118,11 +118,9 @@ protected:
     {
       return (m_Edge == r.m_Edge);
     }
-    bool
-    operator!=(const FrontAtom & r) const
-    {
-      return (m_Edge != r.m_Edge);
-    }
+
+    ITK_UNEQUAL_OPERATOR_MEMBER_FUNCTION(FrontAtom);
+
     bool
     operator<(const FrontAtom & r) const
     {
@@ -170,29 +168,13 @@ public:
   }
 
   // Iteration methods.
-  bool
-  operator==(Self & r) const
-  {
-    return (m_Start == r.m_Start);
-  }
-
   bool
   operator==(const Self & r) const
   {
     return (m_Start == r.m_Start);
   }
 
-  bool
-  operator!=(Self & r) const
-  {
-    return (!(this->operator==(r)));
-  }
-
-  bool
-  operator!=(const Self & r) const
-  {
-    return (!(this->operator==(r)));
-  }
+  ITK_UNEQUAL_OPERATOR_MEMBER_FUNCTION(Self);
 
   Self &
   operator++();
@@ -228,17 +210,17 @@ protected:
 
 protected:
   /** Mesh on which we propagate the front */
-  MeshType * m_Mesh;
+  MeshType * m_Mesh{};
   /** Initial seed of the front */
-  QEType * m_Seed;
+  QEType * m_Seed{};
   /** Whether the iterator is active */
-  bool m_Start;
+  bool m_Start{};
   /** The active front */
-  FrontTypePointer m_Front;
+  FrontTypePointer m_Front{};
   /** The already visited points */
-  IsVisitedPointerType m_IsPointVisited;
+  IsVisitedPointerType m_IsPointVisited{};
   /** The current edge at this stage of iteration */
-  QEType * m_CurrentEdge;
+  QEType * m_CurrentEdge{};
 };
 
 /**
@@ -254,8 +236,8 @@ public:
   /** Hierarchy type alias and values. */
   using Self = QuadEdgeMeshFrontIterator;
   using Superclass = QuadEdgeMeshFrontBaseIterator<TMesh, TQE>;
-  using MeshType = typename Superclass::MeshType;
-  using QEType = typename Superclass::QEType;
+  using typename Superclass::MeshType;
+  using typename Superclass::QEType;
 
 public:
   /** Object creation methods. */
@@ -283,8 +265,8 @@ public:
   /** Hierarchy type alias & values. */
   using Self = QuadEdgeMeshConstFrontIterator;
   using Superclass = QuadEdgeMeshFrontBaseIterator<TMesh, TQE>;
-  using QEType = typename Superclass::QEType;
-  using MeshType = typename Superclass::MeshType;
+  using typename Superclass::QEType;
+  using typename Superclass::MeshType;
   using NoConstType = QuadEdgeMeshFrontIterator<MeshType, QEType>;
 
 public:
