@@ -60,17 +60,13 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
-  /** Method for creation through the object factory. */
-  itkTypeMacro(LandmarkSpatialObject, PointBasedSpatialObject);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(LandmarkSpatialObject);
 
 protected:
   LandmarkSpatialObject();
   ~LandmarkSpatialObject() override = default;
 
-  /** Method to print the object. */
-  void
-  PrintSelf(std::ostream & os, Indent indent) const override;
-
   typename LightObject::Pointer
   InternalClone() const override;
 };
