@@ -135,7 +135,7 @@ itkMetaArrowConverterTest(int argc, char * argv[])
   auto * newMetaArrow = dynamic_cast<MetaArrow *>(converter->SpatialObjectToMetaObject(itkArrow));
   if (newMetaArrow == nullptr)
   {
-    itkGenericExceptionMacro(<< "Failed to downcast from MetaObject to MetaArrow");
+    itkGenericExceptionMacro("Failed to downcast from MetaObject to MetaArrow");
   }
 
   // check length
@@ -269,12 +269,9 @@ itkMetaArrowConverterTest(int argc, char * argv[])
   mDirectionNorm[0] = mDirection[0];
   mDirectionNorm[1] = mDirection[1];
   mDirectionNorm[2] = mDirection[2];
-  if (itk::Math::NotExactlyEquals(mDirection[0],
-                                  itk::NumericTraits<SpatialObjectType::VectorType::ValueType>::ZeroValue()) ||
-      itk::Math::NotExactlyEquals(mDirection[1],
-                                  itk::NumericTraits<SpatialObjectType::VectorType::ValueType>::ZeroValue()) ||
-      itk::Math::NotExactlyEquals(mDirection[2],
-                                  itk::NumericTraits<SpatialObjectType::VectorType::ValueType>::ZeroValue()))
+  if (itk::Math::NotExactlyEquals(mDirection[0], SpatialObjectType::VectorType::ValueType{}) ||
+      itk::Math::NotExactlyEquals(mDirection[1], SpatialObjectType::VectorType::ValueType{}) ||
+      itk::Math::NotExactlyEquals(mDirection[2], SpatialObjectType::VectorType::ValueType{}))
   {
     mDirectionNorm.Normalize();
   }
@@ -344,12 +341,9 @@ itkMetaArrowConverterTest(int argc, char * argv[])
 
   // check direction (note: need to normalize before comparing)
   SpatialObjectType::VectorType reLoadDirectionNorm = reLoad->GetDirectionInWorldSpace();
-  if (itk::Math::NotExactlyEquals(reLoadDirectionNorm[0],
-                                  itk::NumericTraits<SpatialObjectType::VectorType::ValueType>::ZeroValue()) ||
-      itk::Math::NotExactlyEquals(reLoadDirectionNorm[1],
-                                  itk::NumericTraits<SpatialObjectType::VectorType::ValueType>::ZeroValue()) ||
-      itk::Math::NotExactlyEquals(reLoadDirectionNorm[2],
-                                  itk::NumericTraits<SpatialObjectType::VectorType::ValueType>::ZeroValue()))
+  if (itk::Math::NotExactlyEquals(reLoadDirectionNorm[0], SpatialObjectType::VectorType::ValueType{}) ||
+      itk::Math::NotExactlyEquals(reLoadDirectionNorm[1], SpatialObjectType::VectorType::ValueType{}) ||
+      itk::Math::NotExactlyEquals(reLoadDirectionNorm[2], SpatialObjectType::VectorType::ValueType{}))
   {
     reLoadDirectionNorm.Normalize();
   }
