@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@
 #ifndef itkTransform_h
 #define itkTransform_h
 
+#include <type_traits> // For std::enable_if
 #include "itkTransformBase.h"
 #include "itkVector.h"
 #include "itkSymmetricSecondRankTensor.h"
@@ -30,7 +31,7 @@
 namespace itk
 {
 /**
- *\class Transform
+ * \class Transform
  * \brief Transform points and vectors from an input space to an output space.
  *
  * This abstract class defines the generic interface for a geometric
@@ -70,7 +71,7 @@ namespace itk
  *                                                             const InputPointType & x,
  *                                                             JacobianPositionType &jacobian ) const;<br>
  *
- * Since TranformVector and TransformCovariantVector have multiple
+ * Since TransformVector and TransformCovariantVector have multiple
  * overloaded methods from the base class, subclasses must specify:<br>
  *  using Superclass::TransformVector;<br>
  *  using Superclass::TransformCovariantVector;<br>
@@ -78,7 +79,7 @@ namespace itk
  *
  * \ingroup ITKTransform
  */
-template <typename TParametersValueType, unsigned int NInputDimensions = 3, unsigned int NOutputDimensions = 3>
+template <typename TParametersValueType, unsigned int VInputDimension = 3, unsigned int VOutputDimension = 3>
 class ITK_TEMPLATE_EXPORT Transform : public TransformBaseTemplate<TParametersValueType>
 {
 public:
@@ -90,12 +91,12 @@ public:
   using Pointer = SmartPointer<Self>;
   using ConstPointer = SmartPointer<const Self>;
 
-  /** Run-time type information (and related methods). */
-  itkTypeMacro(Transform, TransformBaseTemplate);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(Transform);
 
   /** Dimension of the domain space. */
-  static constexpr unsigned int InputSpaceDimension = NInputDimensions;
-  static constexpr unsigned int OutputSpaceDimension = NOutputDimensions;
+  static constexpr unsigned int InputSpaceDimension = VInputDimension;
+  static constexpr unsigned int OutputSpaceDimension = VOutputDimension;
 
   /** define the Clone method */
   itkCloneMacro(Self);
@@ -104,21 +105,35 @@ public:
   unsigned int
   GetInputSpaceDimension() const override
   {
-    return NInputDimensions;
+    return VInputDimension;
   }
 
   /** Get the size of the output space */
   unsigned int
   GetOutputSpaceDimension() const override
   {
-    return NOutputDimensions;
+    return VOutputDimension;
   }
 
+
+  /* For storing the  name of InputSpace */
+  itkSetMacro(InputSpaceName, std::string);
+  itkGetConstReferenceMacro(InputSpaceName, std::string);
+
+  /** For storing the  name of InputSpace/OutputSpace.
+
+  InputSpaceName, OutputSpaceName provide identifiers for the world spaces
+  that the transform applied to and the direction of the spatial transformation.
+  The direction of the transform goes from the input space to output space.
+  Typical values include the names of an atlas or a dataset. */
+  itkSetMacro(OutputSpaceName, std::string);
+  itkGetConstReferenceMacro(OutputSpaceName, std::string);
+
   /** Type of the input parameters. */
-  using FixedParametersType = typename Superclass::FixedParametersType;
-  using FixedParametersValueType = typename Superclass::FixedParametersValueType;
-  using ParametersType = typename Superclass::ParametersType;
-  using ParametersValueType = typename Superclass::ParametersValueType;
+  using typename Superclass::FixedParametersType;
+  using typename Superclass::FixedParametersValueType;
+  using typename Superclass::ParametersType;
+  using typename Superclass::ParametersValueType;
   using DerivativeType = Array<ParametersValueType>;
 
   /** Type of the scalar representing coordinate and vector elements. */
@@ -126,41 +141,41 @@ public:
 
   /** Type of the Jacobian matrix. */
   using JacobianType = Array2D<ParametersValueType>;
-  using JacobianPositionType = vnl_matrix_fixed<ParametersValueType, NOutputDimensions, NInputDimensions>;
-  using InverseJacobianPositionType = vnl_matrix_fixed<ParametersValueType, NInputDimensions, NOutputDimensions>;
+  using JacobianPositionType = vnl_matrix_fixed<ParametersValueType, VOutputDimension, VInputDimension>;
+  using InverseJacobianPositionType = vnl_matrix_fixed<ParametersValueType, VInputDimension, VOutputDimension>;
 
   /** Standard vector type for this class. */
-  using InputVectorType = Vector<TParametersValueType, NInputDimensions>;
-  using OutputVectorType = Vector<TParametersValueType, NOutputDimensions>;
+  using InputVectorType = Vector<TParametersValueType, VInputDimension>;
+  using OutputVectorType = Vector<TParametersValueType, VOutputDimension>;
 
   /** Standard variable length vector type for this class
    *  this provides an interface for the VectorImage class */
   using InputVectorPixelType = VariableLengthVector<TParametersValueType>;
   using OutputVectorPixelType = VariableLengthVector<TParametersValueType>;
 
-  /* Standard symmetric second rank tenosr type for this class */
-  using InputSymmetricSecondRankTensorType = SymmetricSecondRankTensor<TParametersValueType, NInputDimensions>;
-  using OutputSymmetricSecondRankTensorType = SymmetricSecondRankTensor<TParametersValueType, NOutputDimensions>;
+  /* Standard symmetric second rank tensor type for this class */
+  using InputSymmetricSecondRankTensorType = SymmetricSecondRankTensor<TParametersValueType, VInputDimension>;
+  using OutputSymmetricSecondRankTensorType = SymmetricSecondRankTensor<TParametersValueType, VOutputDimension>;
 
   /* Standard tensor type for this class */
   using InputDiffusionTensor3DType = DiffusionTensor3D<TParametersValueType>;
   using OutputDiffusionTensor3DType = DiffusionTensor3D<TParametersValueType>;
 
   /** Standard covariant vector type for this class */
-  using InputCovariantVectorType = CovariantVector<TParametersValueType, NInputDimensions>;
-  using OutputCovariantVectorType = CovariantVector<TParametersValueType, NOutputDimensions>;
+  using InputCovariantVectorType = CovariantVector<TParametersValueType, VInputDimension>;
+  using OutputCovariantVectorType = CovariantVector<TParametersValueType, VOutputDimension>;
 
   /** Standard vnl_vector type for this class. */
-  using InputVnlVectorType = vnl_vector_fixed<TParametersValueType, NInputDimensions>;
-  using OutputVnlVectorType = vnl_vector_fixed<TParametersValueType, NOutputDimensions>;
+  using InputVnlVectorType = vnl_vector_fixed<TParametersValueType, VInputDimension>;
+  using OutputVnlVectorType = vnl_vector_fixed<TParametersValueType, VOutputDimension>;
 
   /** Standard coordinate point type for this class */
-  using InputPointType = Point<TParametersValueType, NInputDimensions>;
-  using OutputPointType = Point<TParametersValueType, NOutputDimensions>;
+  using InputPointType = Point<TParametersValueType, VInputDimension>;
+  using OutputPointType = Point<TParametersValueType, VOutputDimension>;
 
   /** Base inverse transform type. This type should not be changed to the
    * concrete inverse transform type or inheritance would be lost. */
-  using InverseTransformBaseType = Transform<TParametersValueType, NOutputDimensions, NInputDimensions>;
+  using InverseTransformBaseType = Transform<TParametersValueType, VOutputDimension, VInputDimension>;
 
   using InverseTransformBasePointer = typename InverseTransformBaseType::Pointer;
 
@@ -170,7 +185,7 @@ public:
   using InputDirectionMatrix = Matrix<double, Self::InputSpaceDimension, Self::InputSpaceDimension>;
   using DirectionChangeMatrix = Matrix<double, Self::OutputSpaceDimension, Self::InputSpaceDimension>;
 
-  using NumberOfParametersType = typename Superclass::NumberOfParametersType;
+  using typename Superclass::NumberOfParametersType;
 
   /**  Method to transform a point.
    * \warning This method must be thread-safe. See, e.g., its use
@@ -329,7 +344,7 @@ public:
   /** Set the transformation parameters and update internal transformation.
    * SetParameters gives the transform the option to set it's
    * parameters by keeping a reference to the parameters, or by
-   * copying.  To force the transform to copy it's parameters call
+   * copying.  To force the transform to copy its parameters call
    * SetParametersByValue.
    * \sa SetParametersByValue
    */
@@ -406,14 +421,14 @@ public:
     return this->GetNumberOfParameters();
   }
 
-  /** Return the number of parameters that completely define the Transfom  */
+  /** Return the number of parameters that completely define the Transform  */
   NumberOfParametersType
   GetNumberOfParameters() const override
   {
     return this->m_Parameters.Size();
   }
 
-  /** Return the number of parameters that define the constant elements of a Transfom  */
+  /** Return the number of parameters that define the constant elements of a Transform  */
   virtual NumberOfParametersType
   GetNumberOfFixedParameters() const
   {
@@ -425,7 +440,7 @@ public:
    * the transform is returned in the inverseTransform variable passed by the
    * user.  The inverse is recomputed if this current transform has been
    * modified.
-   * This method is intended to be overriden as needed by derived classes.
+   * This method is intended to be overridden as needed by derived classes.
    *
    */
   bool
@@ -450,7 +465,7 @@ public:
   std::string
   GetTransformTypeAsString() const override;
 
-  using TransformCategoryEnum = typename Superclass::TransformCategoryEnum;
+  using typename Superclass::TransformCategoryEnum;
 
   /** Indicates the category transform.
    *  e.g. an affine transform, or a local one, e.g. a deformation field.
@@ -542,6 +557,25 @@ public:
   itkLegacyMacro(virtual void ComputeInverseJacobianWithRespectToPosition(const InputPointType & x,
                                                                           JacobianType &         jacobian) const);
 
+  /** Apply this transform to an image without resampling.
+   *
+   * Updates image metadata (origin, spacing, direction cosines matrix) in place.
+   *
+   * Only available when input and output space are of the same dimension.
+   * Only works properly for linear transforms.
+   *
+   * The image parameter may be either a SmartPointer or a raw pointer.
+   * */
+  template <typename TImage>
+  std::enable_if_t<TImage::ImageDimension == VInputDimension && TImage::ImageDimension == VOutputDimension, void>
+  ApplyToImageMetadata(TImage * image) const;
+  template <typename TImage>
+  std::enable_if_t<TImage::ImageDimension == VInputDimension && TImage::ImageDimension == VOutputDimension, void>
+  ApplyToImageMetadata(SmartPointer<TImage> image) const
+  {
+    this->ApplyToImageMetadata(image.GetPointer()); // Delegate to the raw pointer signature
+  }
+
 protected:
   /**
    * Clone the current transform.
@@ -551,7 +585,9 @@ protected:
   typename LightObject::Pointer
   InternalClone() const override;
 
-  Transform();
+  /** Default-constructor. Creates a transform, having empty `Parameters` and `FixedParameters`. */
+  Transform() = default;
+
   Transform(NumberOfParametersType numberOfParameters);
 #if defined(__GNUC__)
   // A bug in some versions of the GCC and Clang compilers
@@ -563,16 +599,27 @@ protected:
 #else
   ~Transform() override = default;
 #endif
-  mutable ParametersType      m_Parameters;
-  mutable FixedParametersType m_FixedParameters;
+  mutable ParametersType      m_Parameters{};
+  mutable FixedParametersType m_FixedParameters{};
 
   OutputDiffusionTensor3DType
   PreservationOfPrincipalDirectionDiffusionTensor3DReorientation(const InputDiffusionTensor3DType &,
                                                                  const InverseJacobianPositionType &) const;
 
-  mutable DirectionChangeMatrix m_DirectionChange;
+  /** Returns the inverse of the specified transform. Returns null if it cannot invert the transform. Helper function
+   * for the implementation of `GetInverseTransform()` in derived transform classes. */
+  template <typename TTransform>
+  static InverseTransformBasePointer
+  InvertTransform(const TTransform & transform)
+  {
+    const auto inverse = TTransform::New();
+    return transform.GetInverse(inverse) ? inverse.GetPointer() : nullptr;
+  }
 
 private:
+  std::string m_InputSpaceName{};
+  std::string m_OutputSpaceName{};
+
   template <typename TType>
   static std::string
   GetTransformTypeAsString(TType *)
