@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,7 +19,7 @@
 #include <iostream>
 
 #include "itkRigid3DPerspectiveTransform.h"
-
+#include "itkTestingMacros.h"
 
 int
 itkRigid3DPerspectiveTransformTest(int, char *[])
@@ -35,19 +35,63 @@ itkRigid3DPerspectiveTransformTest(int, char *[])
 
   bool Ok = true;
 
+  // Test exceptions
+  {
+    auto transform = TransformType::New();
+
+    typename TransformType::InputVectorType vector = itk::MakeVector(1.0, 4.0, 9.0);
+    ITK_TRY_EXPECT_EXCEPTION(transform->TransformVector(vector));
+
+    typename TransformType::InputVnlVectorType vnlVector;
+    vnlVector.fill(1.0);
+    ITK_TRY_EXPECT_EXCEPTION(transform->TransformVector(vnlVector));
+
+    typename TransformType::InputCovariantVectorType covVector;
+    covVector.Fill(1.0);
+    ITK_TRY_EXPECT_EXCEPTION(transform->TransformCovariantVector(covVector));
+
+    auto                                         point = itk::MakeFilled<typename TransformType::InputPointType>(1.0);
+    typename TransformType::JacobianPositionType jacobianPosition;
+    ITK_TRY_EXPECT_EXCEPTION(transform->ComputeJacobianWithRespectToPosition(point, jacobianPosition));
+  }
+
+  // Exercise basic object methods and test Set/Get macros
+  {
+    auto transform = TransformType::New();
+
+    ITK_EXERCISE_BASIC_OBJECT_METHODS(transform, Rigid3DPerspectiveTransform, Transform);
+
+
+    typename TransformType::OffsetType fixedOffset;
+    fixedOffset.Fill(0);
+
+    transform->SetFixedOffset(fixedOffset);
+    ITK_TEST_SET_GET_VALUE(fixedOffset, transform->GetFixedOffset());
+
+    typename TransformType::InputPointType centerOfRotation;
+    centerOfRotation.Fill(0);
+    transform->SetCenterOfRotation(centerOfRotation);
+    ITK_TEST_SET_GET_VALUE(centerOfRotation, transform->GetCenterOfRotation());
+
+    // This transform has no fixed parameters; empty method body; called for coverage purposes
+    typename TransformType::FixedParametersType::ValueType fixedParametersValues = 0;
+    typename TransformType::FixedParametersType            fixedParameters;
+    fixedParameters.Fill(fixedParametersValues);
+    transform->SetFixedParameters(fixedParameters);
+  }
 
   /* Create a 3D identity transformation and show its parameters */
   {
-    TransformType::Pointer identityTransform = TransformType::New();
+    auto identityTransform = TransformType::New();
     identityTransform->SetFocalDistance(focal);
 
     TransformType::OffsetType offset = identityTransform->GetOffset();
     std::cout << "Vector from instantiating an identity transform:  ";
     std::cout << offset << std::endl;
 
-    for (unsigned int i = 0; i < N; i++)
+    for (unsigned int i = 0; i < N; ++i)
     {
-      if (std::fabs(offset[i] - 0.0) > epsilon)
+      if (itk::Math::abs(offset[i] - 0.0) > epsilon)
       {
         Ok = false;
         break;
@@ -62,21 +106,22 @@ itkRigid3DPerspectiveTransformTest(int, char *[])
 
   /* Create a Rigid 3D transform with translation */
   {
-    TransformType::Pointer translation = TransformType::New();
+    auto translation = TransformType::New();
     translation->SetFocalDistance(focal);
 
     TransformType::OffsetType ioffset;
     ioffset.Fill(0.0);
 
     translation->SetOffset(ioffset);
+    ITK_TEST_SET_GET_VALUE(ioffset, translation->GetOffset());
 
     TransformType::OffsetType offset = translation->GetOffset();
     std::cout << "pure Translation test:  ";
     std::cout << offset << std::endl;
 
-    for (unsigned int i = 0; i < N; i++)
+    for (unsigned int i = 0; i < N; ++i)
     {
-      if (std::fabs(offset[i] - ioffset[i]) > epsilon)
+      if (itk::Math::abs(offset[i] - ioffset[i]) > epsilon)
       {
         Ok = false;
         break;
@@ -100,9 +145,9 @@ itkRigid3DPerspectiveTransformTest(int, char *[])
       s[1] = q[1] * factor;
       TransformType::OutputPointType r;
       r = translation->TransformPoint(p);
-      for (unsigned int i = 0; i < N - 1; i++)
+      for (unsigned int i = 0; i < N - 1; ++i)
       {
-        if (std::fabs(s[i] - r[i]) > epsilon)
+        if (itk::Math::abs(s[i] - r[i]) > epsilon)
         {
           Ok = false;
           break;
@@ -124,7 +169,7 @@ itkRigid3DPerspectiveTransformTest(int, char *[])
 
   /* Create a Rigid 3D transform with a rotation */
   {
-    TransformType::Pointer rigid = TransformType::New();
+    auto rigid = TransformType::New();
     rigid->SetFocalDistance(focal);
 
     TransformType::OffsetType ioffset;
@@ -146,6 +191,7 @@ itkRigid3DPerspectiveTransformTest(int, char *[])
 
     rotation.Set(axis, angle);
     rigid->SetRotation(rotation);
+    ITK_TEST_SET_GET_VALUE(rotation, rigid->GetRotation());
 
     {
       // Project an itk::Point
@@ -159,9 +205,9 @@ itkRigid3DPerspectiveTransformTest(int, char *[])
       s[1] = q[1] * factor;
       TransformType::OutputPointType r;
       r = rigid->TransformPoint(p);
-      for (unsigned int i = 0; i < N - 1; i++)
+      for (unsigned int i = 0; i < N - 1; ++i)
       {
-        if (std::fabs(s[i] - r[i]) > epsilon)
+        if (itk::Math::abs(s[i] - r[i]) > epsilon)
         {
           Ok = false;
           break;
