@@ -147,7 +147,7 @@ itkBSplineSmoothingOnUpdateDisplacementFieldTransformTest(int, char *[])
     for (int j = -2; j < 3; ++j)
     {
       unsigned int index = outlier + static_cast<unsigned int>(i * (int)(dimLength * dimensions) + j);
-      std::cout << params(index) << " ";
+      std::cout << params(index) << ' ';
       if (itk::Math::AlmostEquals(params(index), paramsFillValue))
       {
         std::cout << "Expected to read a smoothed value at this index."
@@ -220,7 +220,7 @@ itkBSplineSmoothingOnUpdateDisplacementFieldTransformTest(int, char *[])
     for (int j = -2; j < 3; ++j)
     {
       unsigned int index = outlier + static_cast<unsigned int>(i * (int)(dimLength * dimensions) + j);
-      std::cout << params(index) << " ";
+      std::cout << params(index) << ' ';
       if (itk::Math::AlmostEquals(params(index), paramsFillValue))
       {
         std::cout << "Expected to read a smoothed value at this index."
