@@ -90,8 +90,8 @@ public:
   using OutputImagePointer = typename TOutputImage::Pointer;
   using OutputImageRegionType = typename TOutputImage::RegionType;
 
-  /** Run-time type information (and related methods). */
-  itkTypeMacro(VectorExpandImageFilter, ImageToImageFilter);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(VectorExpandImageFilter);
 
   /** ImageDimension enumeration */
   static constexpr unsigned int ImageDimension = TInputImage::ImageDimension;
@@ -183,8 +183,8 @@ protected:
   BeforeThreadedGenerateData() override;
 
 private:
-  ExpandFactorsArrayType m_ExpandFactors;
-  InterpolatorPointer    m_Interpolator;
+  ExpandFactorsArrayType m_ExpandFactors{};
+  InterpolatorPointer    m_Interpolator{};
 };
 } // end namespace itk
 
