@@ -122,8 +122,8 @@ public:
   using typename Superclass::InputImageType;
   using typename Superclass::InputImagePointer;
 
-  /** Run-time type information (and related methods). */
-  itkTypeMacro(VectorRescaleIntensityImageFilter, UnaryFunctorImageFilter);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(VectorRescaleIntensityImageFilter);
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -160,11 +160,11 @@ protected:
   ~VectorRescaleIntensityImageFilter() override = default;
 
 private:
-  InputRealType m_Scale;
-  InputRealType m_Shift;
+  InputRealType m_Scale{};
+  InputRealType m_Shift{};
 
-  InputRealType  m_InputMaximumMagnitude;
-  OutputRealType m_OutputMaximumMagnitude;
+  InputRealType  m_InputMaximumMagnitude{};
+  OutputRealType m_OutputMaximumMagnitude{};
 };
 } // end namespace itk
 
