@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -41,13 +41,13 @@ itkBinaryProjectionImageFilterTest(int argc, char * argv[])
   using ImageType = itk::Image<PixelType, dim>;
 
   using ReaderType = itk::ImageFileReader<ImageType>;
-  ReaderType::Pointer reader = ReaderType::New();
+  auto reader = ReaderType::New();
   reader->SetFileName(argv[1]);
 
   // produce an image with 3 labels: 0 (background), 100 and 200
 
   using LabelerType = itk::ThresholdLabelerImageFilter<ImageType, ImageType>;
-  LabelerType::Pointer labeler = LabelerType::New();
+  auto labeler = LabelerType::New();
   labeler->SetInput(reader->GetOutput());
   LabelerType::RealThresholdVector thresholds;
   thresholds.push_back(100);
@@ -55,13 +55,13 @@ itkBinaryProjectionImageFilterTest(int argc, char * argv[])
   labeler->SetRealThresholds(thresholds);
 
   using ChangeType = itk::ChangeLabelImageFilter<ImageType, ImageType>;
-  ChangeType::Pointer change = ChangeType::New();
+  auto change = ChangeType::New();
   change->SetInput(labeler->GetOutput());
   change->SetChange(1, 100);
   change->SetChange(2, 200);
 
   using FilterType = itk::BinaryProjectionImageFilter<ImageType, ImageType>;
-  FilterType::Pointer filter = FilterType::New();
+  auto filter = FilterType::New();
   filter->SetInput(change->GetOutput());
 
   // Exercise Set/Get methods for Foreground Value
@@ -89,7 +89,7 @@ itkBinaryProjectionImageFilterTest(int argc, char * argv[])
   itk::SimpleFilterWatcher watcher(filter, "filter");
 
   using WriterType = itk::ImageFileWriter<ImageType>;
-  WriterType::Pointer writer = WriterType::New();
+  auto writer = WriterType::New();
   writer->SetInput(filter->GetOutput());
   writer->SetFileName(argv[2]);
 
