@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -27,7 +27,7 @@
 namespace itk
 {
 /**
- *\class ShapeUniqueLabelMapFilter
+ * \class ShapeUniqueLabelMapFilter
  * \brief Remove some pixels in the label object according to the value of their shape attribute to ensure that a pixel
  * is not in to objects
  *
@@ -69,8 +69,8 @@ public:
   /** Standard New method. */
   itkNewMacro(Self);
 
-  /** Runtime information support. */
-  itkTypeMacro(ShapeUniqueLabelMapFilter, InPlaceLabelMapFilter);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(ShapeUniqueLabelMapFilter);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   // Begin concept checking
@@ -169,7 +169,7 @@ protected:
 
       bool newMainLine = false;
       // don't check dim 0!
-      for (unsigned int i = 1; i < ImageDimension; i++)
+      for (unsigned int i = 1; i < ImageDimension; ++i)
       {
         if (idx[i] != prevIdx[i])
         {
@@ -317,10 +317,10 @@ protected:
   void
   PrintSelf(std::ostream & os, Indent indent) const override;
 
-  AttributeType m_Attribute;
+  AttributeType m_Attribute{};
 
 private:
-  bool m_ReverseOrdering;
+  bool m_ReverseOrdering{};
   struct LineOfLabelObject
   {
     using LineType = typename LabelObjectType::LineType;
