@@ -31,7 +31,7 @@ zeroSizeCase()
   auto p_image = ImageType::New();
 
   // The image region is empty by default: do not set any region to it and allocate memory
-  p_image->Allocate(true);
+  p_image->AllocateInitialized();
 
   p_filter->SetInput(p_image);
   p_filter->Update();
@@ -114,7 +114,7 @@ itkLabelImageToLabelMapFilterTest(int, char *[])
       index[1] = ctrJ;
       unsigned long val;
       val = map->GetPixel(index);
-      std::cout << "Pixel[" << ctrI << "," << ctrJ << "]: " << val << std::endl;
+      std::cout << "Pixel[" << ctrI << ',' << ctrJ << "]: " << val << std::endl;
       if (((ctrI == 5) || (ctrJ == 5)) && (ctrI != 7) && (ctrJ != 7))
       {
         itkAssertOrThrowMacro((val == 1), "Error in Label Image (foreground).");
