@@ -73,9 +73,8 @@ public:
 #define GIPL_MAGIC_NUMBER2 0x2ae389b8
 
 GiplImageIO::GiplImageIO()
+  : m_Internal(std::make_unique<GiplImageIOInternals>())
 {
-  m_Internal = new GiplImageIOInternals;
-  m_Internal->m_GzFile = nullptr;
   m_ByteOrder = IOByteOrderEnum::BigEndian;
   m_IsCompressed = false;
 }
@@ -94,7 +93,6 @@ GiplImageIO::~GiplImageIO()
   {
     m_Ifstream.close();
   }
-  delete m_Internal;
 }
 
 bool
@@ -105,7 +103,7 @@ GiplImageIO::CanReadFile(const char * filename)
 
   if (!extensionFound)
   {
-    itkDebugMacro(<< "The filename extension is not recognized");
+    itkDebugMacro("The filename extension is not recognized");
     return false;
   }
 
@@ -183,14 +181,14 @@ GiplImageIO::CanWriteFile(const char * name)
 
   if (filename.empty())
   {
-    itkDebugMacro(<< "No filename specified.");
+    itkDebugMacro("No filename specified.");
   }
 
   bool extensionFound = CheckExtension(name);
 
   if (!extensionFound)
   {
-    itkDebugMacro(<< "The filename extension is not recognized");
+    itkDebugMacro("The filename extension is not recognized");
     return false;
   }
 
@@ -1098,7 +1096,7 @@ void
 GiplImageIO::PrintSelf(std::ostream & os, Indent indent) const
 {
   Superclass::PrintSelf(os, indent);
-  os << indent << "PixelType " << m_PixelType << "\n";
+  os << indent << "PixelType " << m_PixelType << '\n';
 }
 
 bool
@@ -1108,7 +1106,7 @@ GiplImageIO::CheckExtension(const char * filename)
 
   if (fname.empty())
   {
-    itkDebugMacro(<< "No filename specified.");
+    itkDebugMacro("No filename specified.");
     return false;
   }
 
