@@ -23,6 +23,7 @@
 #include "itkMath.h"
 #include "itkSingleton.h"
 #include "itkMakeUniqueForOverwrite.h"
+#include "metaImageUtils.h"
 
 namespace itk
 {
@@ -66,7 +67,7 @@ MetaImageIO::PrintSelf(std::ostream & os, Indent indent) const
 {
   Superclass::PrintSelf(os, indent);
   m_MetaImage.PrintInfo();
-  os << indent << "SubSamplingFactor: " << m_SubSamplingFactor << "\n";
+  os << indent << "SubSamplingFactor: " << m_SubSamplingFactor << '\n';
 }
 
 void
@@ -86,7 +87,7 @@ MetaImageIO::CanReadFile(const char * filename)
 
   if (fname.empty())
   {
-    itkDebugMacro(<< "No filename specified.");
+    itkDebugMacro("No filename specified.");
     return false;
   }
 
@@ -404,6 +405,12 @@ MetaImageIO::ReadImageInformation()
 
   std::string classname(this->GetNameOfClass());
   EncapsulateMetaData<std::string>(thisMetaDict, ITK_InputFilterName, classname);
+
+  // metaImage has a Modality tag which is not stored as part of its
+  // metadata dictionary
+  std::string modality;
+  MET_ImageModalityToString(m_MetaImage.Modality(), modality);
+  EncapsulateMetaData<std::string>(thisMetaDict, "Modality", modality);
   //
   // save the metadatadictionary in the MetaImage header.
   // NOTE: The MetaIO library only supports typeless strings as metadata
@@ -630,7 +637,7 @@ MetaImageIO::WriteImageInformation()
       unsigned int i = 0;
       while (i < vval.size() - 1)
       {
-        strs << vval[++i] << " ";
+        strs << vval[++i] << ' ';
       }
       strs << vval[i];
     }
