@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,6 +21,7 @@
 #include "itkImageFileWriter.h"
 #include "itkMetaImageIO.h"
 #include "itkTestingMacros.h"
+#include <algorithm> // For min.
 
 int
 itkMetaImageStreamingWriterIOTest(int argc, char * argv[])
@@ -42,7 +43,7 @@ itkMetaImageStreamingWriterIOTest(int argc, char * argv[])
   using ReaderType = itk::ImageFileReader<ImageType>;
   using WriterType = itk::ImageFileWriter<ImageType>;
 
-  ReaderType::Pointer reader = ReaderType::New();
+  auto reader = ReaderType::New();
   reader->SetImageIO(metaImageIO);
   reader->SetFileName(argv[1]);
   reader->SetUseStreaming(true);
@@ -53,7 +54,7 @@ itkMetaImageStreamingWriterIOTest(int argc, char * argv[])
   ImageType::SizeType   fullsize;
   ImageType::IndexType  index;
 
-  unsigned int numberOfPieces = 10;
+  itk::SizeValueType numberOfPieces = 10;
 
   // We decide how we want to read the image and we split accordingly
   // The image is read slice by slice
@@ -65,17 +66,14 @@ itkMetaImageStreamingWriterIOTest(int argc, char * argv[])
   size[1] = fullsize[1];
   size[2] = 0;
 
-  if (numberOfPieces > fullsize[2])
-  {
-    numberOfPieces = fullsize[2];
-  }
+  numberOfPieces = std::min(numberOfPieces, fullsize[2]);
   unsigned int zsize = fullsize[2] / numberOfPieces;
 
   // Setup the writer
-  WriterType::Pointer writer = WriterType::New();
+  auto writer = WriterType::New();
   writer->SetFileName(argv[2]);
 
-  for (unsigned int i = 0; i < numberOfPieces; i++)
+  for (unsigned int i = 0; i < numberOfPieces; ++i)
   {
     std::cout << "Reading piece " << i + 1 << " of " << numberOfPieces << std::endl;
 
