@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,6 +21,7 @@
 #include "itkImageFileReader.h"
 #include "itkImageFileWriter.h"
 #include "itkAtanRegularizedHeavisideStepFunction.h"
+#include "itkTestingMacros.h"
 
 int
 itkScalarChanAndVeseDenseLevelSetImageFilterTest4(int argc, char * argv[])
@@ -28,9 +29,9 @@ itkScalarChanAndVeseDenseLevelSetImageFilterTest4(int argc, char * argv[])
 
   if (argc < 4)
   {
-    std::cerr << "Missing arguments" << std::endl;
-    std::cerr << "Usage: " << std::endl;
-    std::cerr << argv[0] << "inputLevelSetImage inputFeatureImage ";
+    std::cerr << "Missing parameters." << std::endl;
+    std::cerr << "Usage: " << itkNameOfTestExecutableMacro(argv);
+    std::cerr << "inputLevelSetImage inputFeatureImage ";
     std::cerr << " outputLevelSetImage CurvatureWeight AreaWeight";
     std::cerr << " ReinitializationWeight VolumeWeight Volume" << std::endl;
     return EXIT_FAILURE;
@@ -73,21 +74,28 @@ itkScalarChanAndVeseDenseLevelSetImageFilterTest4(int argc, char * argv[])
 
   using DomainFunctionType = itk::AtanRegularizedHeavisideStepFunction<ScalarPixelType, ScalarPixelType>;
 
-  DomainFunctionType::Pointer domainFunction = DomainFunctionType::New();
+  auto domainFunction = DomainFunctionType::New();
 
   domainFunction->SetEpsilon(epsilon);
 
-  LevelSetReaderType::Pointer levelSetReader1 = LevelSetReaderType::New();
+  auto levelSetReader1 = LevelSetReaderType::New();
   levelSetReader1->SetFileName(argv[1]);
-  levelSetReader1->Update();
 
-  FeatureReaderType::Pointer featureReader = FeatureReaderType::New();
+  ITK_TRY_EXPECT_NO_EXCEPTION(levelSetReader1->Update());
+
+
+  auto featureReader = FeatureReaderType::New();
   featureReader->SetFileName(argv[2]);
-  featureReader->Update();
 
-  MultiLevelSetType::Pointer levelSetFilter = MultiLevelSetType::New();
+  ITK_TRY_EXPECT_NO_EXCEPTION(featureReader->Update());
+
+
+  auto levelSetFilter = MultiLevelSetType::New();
+
+  ITK_EXERCISE_BASIC_OBJECT_METHODS(
+    levelSetFilter, ScalarChanAndVeseDenseLevelSetImageFilter, MultiphaseDenseFiniteDifferenceImageFilter);
+
 
-  levelSetReader1->Update();
   levelSetFilter->SetFunctionCount(1); // Protected ?
   levelSetFilter->SetFeatureImage(featureReader->GetOutput());
   levelSetFilter->SetLevelSet(0, levelSetReader1->GetOutput());
@@ -105,26 +113,18 @@ itkScalarChanAndVeseDenseLevelSetImageFilterTest4(int argc, char * argv[])
   levelSetFilter->GetDifferenceFunction(0)->SetLambda1(l1);
   levelSetFilter->GetDifferenceFunction(0)->SetLambda2(l2);
 
+  ITK_TRY_EXPECT_NO_EXCEPTION(levelSetFilter->Update());
 
-  levelSetFilter->Update();
 
-  WriterType::Pointer writer1 = WriterType::New();
+  auto writer1 = WriterType::New();
 
   writer1->SetInput(levelSetFilter->GetOutput());
   writer1->UseCompressionOn();
 
   writer1->SetFileName(argv[3]);
 
-  try
-  {
-    writer1->Update();
-  }
-  catch (const itk::ExceptionObject & excep)
-  {
-    std::cerr << "Exception caught !" << std::endl;
-    std::cerr << excep << std::endl;
-    return EXIT_FAILURE;
-  }
+  ITK_TRY_EXPECT_NO_EXCEPTION(writer1->Update());
+
 
   return EXIT_SUCCESS;
 }
