@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,11 +23,11 @@ namespace itk
 namespace fem
 {
 // Overload the CreateAnother() method
-::itk::LightObject::Pointer
+itk::LightObject::Pointer
 Element3DC0LinearHexahedronStrain::CreateAnother() const
 {
-  ::itk::LightObject::Pointer smartPtr;
-  Pointer                     copyPtr = Self::New();
+  itk::LightObject::Pointer smartPtr;
+  Pointer                   copyPtr = Self::New();
 
   copyPtr->SetNode(0, this->GetNode(0));
   copyPtr->SetNode(1, this->GetNode(1));
@@ -53,7 +53,7 @@ Element3DC0LinearHexahedronStrain::Element3DC0LinearHexahedronStrain(NodeIDType
   : Superclass()
 {
   // Set the geometrical points
-  for (int k = 0; k < 8; k++)
+  for (int k = 0; k < 8; ++k)
   {
     this->SetNode(k, ns_[k]);
   }
