@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,14 +18,19 @@
 
 
 #include "itkFEMElement2DC0LinearLineStress.h"
-#include "itkFEMSpatialObjectWriter.h"
-
+#include "itkFEMElementBase.h"
+#include "itkFEMFactoryBase.h"
+#include "itkFEMMaterialLinearElasticity.h"
+#include "itkFEMLoadBCMFC.h"
+#include "itkFEMLoadBC.h"
+#include "itkFEMLoadNode.h"
+#include "itkFEMObject.h"
 
 int
 itkFEMObjectTest2(int, char *[])
 {
   // Need to register default FEM object types,
-  // and setup SpatialReader to recognize FEM types
+  // and setup spatialReader to recognize FEM types
   // which is all currently done as a HACK in
   // the initialization of the itk::FEMFactoryBase::GetFactory()
   itk::FEMFactoryBase::GetFactory()->RegisterDefaultTypes();
