@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -25,23 +25,15 @@ namespace Statistics
 {
 NormalVariateGenerator::NormalVariateGenerator()
 {
-  m_Scale = ((double)30000000.0);
-  m_Rscale = ((double)(1.0 / m_Scale));
-  m_Rcons = ((double)(1.0 / (2.0 * 1024.0 * 1024.0 * 1024.0)));
-  m_ELEN = 7; /*  LEN must be 2 ** ELEN       */
-  m_LEN = 128;
-  m_LMASK = (4 * (m_LEN - 1));
-  m_TLEN = (8 * m_LEN);
-  m_Vec1 = new int[m_TLEN];
+  m_Scale = 30000000.0;
+  m_Rscale = 1.0 / m_Scale;
+  m_Rcons = 1.0 / (2.0 * 1024.0 * 1024.0 * 1024.0);
 
   m_Gausssave = nullptr;
   this->Initialize(0);
 }
 
-NormalVariateGenerator::~NormalVariateGenerator()
-{
-  delete[] m_Vec1;
-}
+NormalVariateGenerator::~NormalVariateGenerator() = default;
 
 void
 NormalVariateGenerator::PrintSelf(std::ostream & os, Indent indent) const
@@ -152,7 +144,7 @@ NormalVariateGenerator::FastNorm()
 
 startpass:
   /*    Count passes    */
-  m_Nslew++;
+  ++m_Nslew;
   /*    Reset index into Saved values   */
   m_Gaussfaze = m_TLEN - 1; /* We will steal the last one   */
   /*    Update pseudo-random and use to choose type of rotation  */
@@ -458,8 +450,8 @@ nextpair:
   tz = -2.0 * std::log((r + 0.5) * m_Rcons); /* Sum of squares */
   ts += tz;
   tz = std::sqrt(tz / tr);
-  m_Vec1[p++] = (int)(m_Scale * tx * tz);
-  m_Vec1[p++] = (int)(m_Scale * ty * tz);
+  m_Vec1[p++] = static_cast<int>(m_Scale * tx * tz);
+  m_Vec1[p++] = static_cast<int>(m_Scale * ty * tz);
   if (p < m_TLEN)
   {
     goto nextpair;
@@ -468,16 +460,16 @@ nextpair:
   /*    Calc correction factor to make sum of squares = TLEN    */
   ts = m_TLEN / ts; /* Should be close to 1.0  */
   tr = std::sqrt(ts);
-  for (p = 0; p < m_TLEN; p++)
+  for (p = 0; p < m_TLEN; ++p)
   {
     tx = m_Vec1[p] * tr;
-    m_Vec1[p] = (int)((tx < 0.0) ? (tx - 0.5) : (tx + 0.5));
+    m_Vec1[p] = static_cast<int>((tx < 0.0) ? (tx - 0.5) : (tx + 0.5));
   }
 
 recalcsumsq:
   /*    Calculate actual sum of squares for correction   */
   ts = 0.0;
-  for (p = 0; p < m_TLEN; p++)
+  for (p = 0; p < m_TLEN; ++p)
   {
     tx = m_Vec1[p];
     ts += (tx * tx);
