@@ -85,8 +85,8 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
-  /** Run-time type information (and related methods). */
-  itkTypeMacro(GPUDemonsRegistrationFilter, GPUPDEDeformableRegistrationFilter);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(GPUDemonsRegistrationFilter);
 
   /** Inherit types from GPUSuperclass. */
   using TimeStepType = typename GPUSuperclass::TimeStepType;
@@ -112,7 +112,7 @@ public:
 
   /** Get the metric value. The metric value is the mean square difference
    * in intensity between the fixed image and transforming moving image
-   * computed over the the overlapping region between the two images.
+   * computed over the overlapping region between the two images.
    * This is value is only available for the previous iteration and
    * NOT the current iteration. */
   double
@@ -144,7 +144,7 @@ protected:
   ApplyUpdate(const TimeStepType & dt) override;
 
 private:
-  bool m_UseMovingImageGradient;
+  bool m_UseMovingImageGradient{};
 };
 
 /** \class GPUDemonsRegistrationFilterFactory
@@ -177,8 +177,8 @@ public:
   /** Method for class instantiation. */
   itkFactorylessNewMacro(Self);
 
-  /** Run-time type information (and related methods). */
-  itkTypeMacro(GPUDemonsRegistrationFilterFactory, itk::ObjectFactoryBase);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(GPUDemonsRegistrationFilterFactory);
 
   /** Register one factory of this type  */
   static void
