@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -43,9 +43,7 @@ itkMeanSquaresImageToImageMetricv4SpeedTest(int argc, char * argv[])
   size.Fill(imageSize);
   ImageType::IndexType index;
   index.Fill(0);
-  ImageType::RegionType region;
-  region.SetSize(size);
-  region.SetIndex(index);
+  ImageType::RegionType  region{ index, size };
   ImageType::SpacingType spacing;
   spacing.Fill(1.0);
   ImageType::PointType origin;
@@ -54,14 +52,14 @@ itkMeanSquaresImageToImageMetricv4SpeedTest(int argc, char * argv[])
   direction.SetIdentity();
 
   /* Create simple test images. */
-  ImageType::Pointer fixedImage = ImageType::New();
+  auto fixedImage = ImageType::New();
   fixedImage->SetRegions(region);
   fixedImage->SetSpacing(spacing);
   fixedImage->SetOrigin(origin);
   fixedImage->SetDirection(direction);
   fixedImage->Allocate();
 
-  ImageType::Pointer movingImage = ImageType::New();
+  auto movingImage = ImageType::New();
   movingImage->SetRegions(region);
   movingImage->SetSpacing(spacing);
   movingImage->SetOrigin(origin);
@@ -95,8 +93,8 @@ itkMeanSquaresImageToImageMetricv4SpeedTest(int argc, char * argv[])
   using FixedTransformType = itk::TranslationTransform<double, imageDimensionality>;
   using MovingTransformType = itk::TranslationTransform<double, imageDimensionality>;
 
-  FixedTransformType::Pointer  fixedTransform = FixedTransformType::New();
-  MovingTransformType::Pointer movingTransform = MovingTransformType::New();
+  auto fixedTransform = FixedTransformType::New();
+  auto movingTransform = MovingTransformType::New();
 
   fixedTransform->SetIdentity();
   movingTransform->SetIdentity();
@@ -104,7 +102,7 @@ itkMeanSquaresImageToImageMetricv4SpeedTest(int argc, char * argv[])
   /* The metric */
   using MetricType = itk::MeanSquaresImageToImageMetricv4<ImageType, ImageType, ImageType>;
 
-  MetricType::Pointer metric = MetricType::New();
+  auto metric = MetricType::New();
 
   /* Assign images and transforms.
    * By not setting a virtual domain image or virtual domain settings,
@@ -122,8 +120,8 @@ itkMeanSquaresImageToImageMetricv4SpeedTest(int argc, char * argv[])
   MetricType::MeasureType    valueReturn1;
   MetricType::DerivativeType derivativeReturn;
 
-  MetricType::MeasureType sum = itk::NumericTraits<MetricType::MeasureType>::ZeroValue();
-  for (int r = 0; r < numberOfReps; r++)
+  MetricType::MeasureType sum{};
+  for (int r = 0; r < numberOfReps; ++r)
   {
     metric->GetValueAndDerivative(valueReturn1, derivativeReturn);
     // Sum results to prevent optimizations
