@@ -44,7 +44,7 @@ namespace itk
  *    SegmentationLevelSetImageFilter), it works by first constructing a scalar
  *    speed term and a vector advection field based on edge features in the
  *    image.  The level set front is then moved according to these two terms
- *    with the addition of a third curvature term to contol the smoothness of
+ *    with the addition of a third curvature term to control the smoothness of
  *    the solution.
  *
  *  \par
@@ -151,8 +151,8 @@ public:
 
   using ScalarValueType = typename CannyFunctionType::ScalarValueType;
 
-  /** Run-time type information (and related methods). */
-  itkTypeMacro(CannySegmentationLevelSetImageFilter, SegmentationLevelSetImageFilter);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(CannySegmentationLevelSetImageFilter);
 
   /** Method for creation through the object factory */
   itkNewMacro(Self);
@@ -202,7 +202,7 @@ protected:
   CannySegmentationLevelSetImageFilter();
 
 private:
-  typename CannyFunctionType::Pointer m_CannyFunction;
+  typename CannyFunctionType::Pointer m_CannyFunction{};
 };
 } // end namespace itk
 
