@@ -82,9 +82,7 @@ itkMultiLevelSetShiImageSubset2DTest(int, char *[])
   InputImageType::IndexType index;
   index.Fill(0);
 
-  InputImageType::RegionType region;
-  region.SetIndex(index);
-  region.SetSize(size);
+  InputImageType::RegionType region{ index, size };
 
   // Input initialization
   auto input = InputImageType::New();
@@ -92,7 +90,7 @@ itkMultiLevelSetShiImageSubset2DTest(int, char *[])
   input->SetSpacing(spacing);
   input->SetOrigin(origin);
   input->Allocate();
-  input->FillBuffer(itk::NumericTraits<InputPixelType>::ZeroValue());
+  input->FillBuffer(InputPixelType{});
 
   index.Fill(910);
   size.Fill(80);
@@ -120,7 +118,7 @@ itkMultiLevelSetShiImageSubset2DTest(int, char *[])
   binary->SetSpacing(spacing);
   binary->SetOrigin(origin);
   binary->Allocate();
-  binary->FillBuffer(itk::NumericTraits<InputPixelType>::ZeroValue());
+  binary->FillBuffer(InputPixelType{});
 
   index.Fill(30);
   size.Fill(40);
