@@ -6,7 +6,7 @@
  *  you may not use this file except in compliance with the License.
  *  You may obtain a copy of the License at
  *
- *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *         https://www.apache.org/licenses/LICENSE-2.0.txt
  *
  *  Unless required by applicable law or agreed to in writing, software
  *  distributed under the License is distributed on an "AS IS" BASIS,
@@ -60,8 +60,8 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
-  /** Standard part of every itk Object. */
-  itkTypeMacro(VoronoiDiagram2DGenerator, MeshSource);
+  /** \see LightObject::GetNameOfClass() */
+  itkOverrideGetNameOfClassMacro(VoronoiDiagram2DGenerator);
 
   /** Convenient type alias. */
   using VoronoidDiagramType = VoronoiDiagram2D<TCoordType>;
@@ -131,9 +131,9 @@ protected:
 
 private:
   unsigned int m_NumberOfSeeds{ 0 };
-  PointType    m_VorBoundary;
-  OutputType   m_OutputVD;
-  SeedsType    m_Seeds;
+  PointType    m_VorBoundary{};
+  OutputType   m_OutputVD{};
+  SeedsType    m_Seeds{};
 
   /** Compare point coordinates in the y direction. */
   static bool
@@ -229,16 +229,16 @@ private:
   unsigned int                 m_PQhashsize{ 0 };
   unsigned int                 m_Nedges{ 0 };
   unsigned int                 m_Nvert{ 0 };
-  FortuneSite *                m_BottomSite;
-  std::vector<FortuneHalfEdge> m_PQHash;
+  FortuneSite *                m_BottomSite{};
+  std::vector<FortuneHalfEdge> m_PQHash{};
 
   unsigned int                   m_ELhashsize{ 0 };
-  FortuneHalfEdge                m_ELleftend;
-  FortuneHalfEdge                m_ELrightend;
-  std::vector<FortuneHalfEdge *> m_ELHash;
+  FortuneHalfEdge                m_ELleftend{};
+  FortuneHalfEdge                m_ELrightend{};
+  std::vector<FortuneHalfEdge *> m_ELHash{};
 
-  FortuneEdge              m_DELETED;
-  std::vector<FortuneSite> m_SeedSites;
+  FortuneEdge              m_DELETED{};
+  std::vector<FortuneSite> m_SeedSites{};
 
   /** Methods to convert the result from Fortune Algorithm into itkMesh
    * structure.
