@@ -20,6 +20,7 @@
 #include "gdcmFragment.h"
 
 #include <iostream>
+#include <limits>
 
 namespace gdcm
 {
@@ -27,7 +28,7 @@ namespace gdcm
 const double *Image::GetSpacing() const
 {
   assert( NumberOfDimensions );
-  return &Spacing[0];
+  return Spacing.data();
 }
 
 double Image::GetSpacing(unsigned int idx) const
@@ -44,8 +45,7 @@ double Image::GetSpacing(unsigned int idx) const
 void Image::SetSpacing(const double *spacing)
 {
   assert( NumberOfDimensions );
-  Spacing = std::vector<double>(spacing,
-    spacing+NumberOfDimensions);
+  Spacing.assign(spacing, spacing+NumberOfDimensions);
 }
 
 void Image::SetSpacing(unsigned int idx, double spacing)
@@ -59,8 +59,8 @@ const double *Image::GetOrigin() const
 {
   assert( NumberOfDimensions );
   if( !Origin.empty() )
-    return &Origin[0];
-  return 0;
+    return Origin.data();
+  return nullptr;
 }
 
 double Image::GetOrigin(unsigned int idx) const
@@ -79,15 +79,14 @@ void Image::SetOrigin(const float *ori)
   Origin.resize( NumberOfDimensions );
   for(unsigned int i = 0; i < NumberOfDimensions; ++i)
     {
-    Origin[i] = ori[i];
+    Origin[i] = static_cast<double>(ori[i]);
     }
 }
 
 void Image::SetOrigin(const double *ori)
 {
   assert( NumberOfDimensions );
-  Origin = std::vector<double>(ori,
-    ori+NumberOfDimensions);
+  Origin.assign(ori, ori+NumberOfDimensions);
 }
 
 void Image::SetOrigin(unsigned int idx, double ori)
@@ -100,8 +99,8 @@ const double *Image::GetDirectionCosines() const
 {
   assert( NumberOfDimensions );
   if( !DirectionCosines.empty() )
-    return &DirectionCosines[0];
-  return 0;
+    return DirectionCosines.data();
+  return nullptr;
 }
 double Image::GetDirectionCosines(unsigned int idx) const
 {
@@ -119,15 +118,14 @@ void Image::SetDirectionCosines(const float *dircos)
   DirectionCosines.resize( 6 );
   for(int i = 0; i < 6; ++i)
     {
-    DirectionCosines[i] = dircos[i];
+    DirectionCosines[i] = static_cast<double>(dircos[i]);
     }
 }
 
 void Image::SetDirectionCosines(const double *dircos)
 {
   assert( NumberOfDimensions );
-  DirectionCosines = std::vector<double>(dircos,
-    dircos+6);
+  DirectionCosines.assign(dircos, dircos+6);
 }
 
 void Image::SetDirectionCosines(unsigned int idx, double dircos)
