@@ -1,4 +1,4 @@
-/* $Id: tif_jpeg.c,v 1.101 2011-02-23 21:58:00 fwarmerdam Exp $ */
+/* $Id: tif_jpeg.c,v 1.111 2012-07-06 18:48:04 bfriesen Exp $ */
 
 /*
  * Copyright (c) 1994-1997 Sam Leffler
@@ -1094,50 +1094,13 @@ JPEGPreDecode(TIFF* tif, uint16 s)
     /* Component 0 should have expected sampling factors */
     if (sp->cinfo.d.comp_info[0].h_samp_factor != sp->h_sampling ||
         sp->cinfo.d.comp_info[0].v_samp_factor != sp->v_sampling) {
-        TIFFWarningExt(tif->tif_clientdata, module,
-            "Improper JPEG sampling factors %d,%d\n"
-            "Apparently should be %d,%d.",
-            sp->cinfo.d.comp_info[0].h_samp_factor,
-            sp->cinfo.d.comp_info[0].v_samp_factor,
-            sp->h_sampling, sp->v_sampling);
-
-        /*
-         * There are potential security issues here
-         * for decoders that have already allocated
-         * buffers based on the expected sampling
-         * factors. Lets check the sampling factors
-         * dont exceed what we were expecting.
-         */
-        if (sp->cinfo.d.comp_info[0].h_samp_factor
-          > sp->h_sampling
-            || sp->cinfo.d.comp_info[0].v_samp_factor
-          > sp->v_sampling) {
-          TIFFErrorExt(tif->tif_clientdata,
-                 module,
-          "Cannot honour JPEG sampling factors"
-          " that exceed those specified.");
-          return (0);
-        }
-
-          /*
-           * XXX: Files written by the Intergraph software
-           * has different sampling factors stored in the
-           * TIFF tags and in the JPEG structures. We will
-           * try to deduce Intergraph files by the presense
-           * of the tag 33918.
-           */
-          if (!TIFFFindField(tif, 33918, TIFF_ANY)) {
-          TIFFWarningExt(tif->tif_clientdata, module,
-          "Decompressor will try reading with "
-          "sampling %d,%d.",
-          sp->cinfo.d.comp_info[0].h_samp_factor,
-          sp->cinfo.d.comp_info[0].v_samp_factor);
-
-            sp->h_sampling = (uint16)
-          sp->cinfo.d.comp_info[0].h_samp_factor;
-            sp->v_sampling = (uint16)
-          sp->cinfo.d.comp_info[0].v_samp_factor;
-          }
+      TIFFErrorExt(tif->tif_clientdata, module,
+               "Improper JPEG sampling factors %d,%d\n"
+               "Apparently should be %d,%d.",
+               sp->cinfo.d.comp_info[0].h_samp_factor,
+               sp->cinfo.d.comp_info[0].v_samp_factor,
+               sp->h_sampling, sp->v_sampling);
+      return (0);
     }
     /* Rest should have sampling factors 1,1 */
     for (ci = 1; ci < sp->cinfo.d.num_components; ci++) {
@@ -1159,11 +1122,11 @@ JPEGPreDecode(TIFF* tif, uint16 s)
   if (td->td_planarconfig == PLANARCONFIG_CONTIG &&
       sp->photometric == PHOTOMETRIC_YCBCR &&
       sp->jpegcolormode == JPEGCOLORMODE_RGB) {
-  /* Convert YCbCr to RGB */
+    /* Convert YCbCr to RGB */
     sp->cinfo.d.jpeg_color_space = JCS_YCbCr;
     sp->cinfo.d.out_color_space = JCS_RGB;
   } else {
-      /* Suppress colorspace handling */
+    /* Suppress colorspace handling */
     sp->cinfo.d.jpeg_color_space = JCS_UNKNOWN;
     sp->cinfo.d.out_color_space = JCS_UNKNOWN;
     if (td->td_planarconfig == PLANARCONFIG_CONTIG &&
@@ -1174,6 +1137,9 @@ JPEGPreDecode(TIFF* tif, uint16 s)
   if (downsampled_output) {
     /* Need to use raw-data interface to libjpeg */
     sp->cinfo.d.raw_data_out = TRUE;
+#if JPEG_LIB_VERSION >= 70
+    sp->cinfo.d.do_fancy_upsampling = FALSE;
+#endif /* JPEG_LIB_VERSION >= 70 */
     tif->tif_decoderow = DecodeRowError;
     tif->tif_decodestrip = JPEGDecodeRaw;
     tif->tif_decodetile = JPEGDecodeRaw;
@@ -1348,18 +1314,23 @@ JPEGDecodeRaw(TIFF* tif, uint8* buf, tmsize_t cc, uint16 s)
 
 #if defined(JPEG_LIB_MK1_OR_12BIT)
     unsigned short* tmpbuf = _TIFFmalloc(sizeof(unsigned short) *
-        sp->cinfo.d.output_width *
-        sp->cinfo.d.num_components);
+                 sp->cinfo.d.output_width *
+                 sp->cinfo.d.num_components);
+    if(tmpbuf==NULL) {
+                        TIFFErrorExt(tif->tif_clientdata, "JPEGDecodeRaw",
+             "Out of memory");
+      return 0;
+                }
 #endif
 
     do {
       jpeg_component_info *compptr;
       int ci, clumpoffset;
 
-                        if( cc < sp->bytesperline * sp->v_sampling ) {
-                            TIFFErrorExt(tif->tif_clientdata, "JPEGDecodeRaw",
-                                         "application buffer not large enough for all data.");
-                            return 0;
+                        if( cc < sp->bytesperline ) {
+        TIFFErrorExt(tif->tif_clientdata, "JPEGDecodeRaw",
+               "application buffer not large enough for all data.");
+        return 0;
                         }
 
       /* Reload downsampled-data buffer if needed */
@@ -1375,20 +1346,25 @@ JPEGDecodeRaw(TIFF* tif, uint8* buf, tmsize_t cc, uint16 s)
        */
       clumpoffset = 0;    /* first sample in clump */
       for (ci = 0, compptr = sp->cinfo.d.comp_info;
-          ci < sp->cinfo.d.num_components;
-          ci++, compptr++) {
+           ci < sp->cinfo.d.num_components;
+           ci++, compptr++) {
         int hsamp = compptr->h_samp_factor;
         int vsamp = compptr->v_samp_factor;
         int ypos;
 
         for (ypos = 0; ypos < vsamp; ypos++) {
           JSAMPLE *inptr = sp->ds_buffer[ci][sp->scancount*vsamp + ypos];
+          JDIMENSION nclump;
 #if defined(JPEG_LIB_MK1_OR_12BIT)
           JSAMPLE *outptr = (JSAMPLE*)tmpbuf + clumpoffset;
 #else
           JSAMPLE *outptr = (JSAMPLE*)buf + clumpoffset;
+          if (cc < (tmsize_t) (clumpoffset + samples_per_clump*(clumps_per_line-1) + hsamp)) {
+            TIFFErrorExt(tif->tif_clientdata, "JPEGDecodeRaw",
+                   "application buffer not large enough for all data, possible subsampling issue");
+            return 0;
+          }
 #endif
-          JDIMENSION nclump;
 
           if (hsamp == 1) {
             /* fast path for at least Cb and Cr */
@@ -1399,7 +1375,7 @@ JPEGDecodeRaw(TIFF* tif, uint8* buf, tmsize_t cc, uint16 s)
           } else {
             int xpos;
 
-      /* general case */
+            /* general case */
             for (nclump = clumps_per_line; nclump-- > 0; ) {
               for (xpos = 0; xpos < hsamp; xpos++)
                 outptr[xpos] = *inptr++;
@@ -1422,9 +1398,9 @@ JPEGDecodeRaw(TIFF* tif, uint8* buf, tmsize_t cc, uint16 s)
           }
         }
         else
-          {         /* 12-bit */
+        {         /* 12-bit */
           int value_pairs = (sp->cinfo.d.output_width
-              * sp->cinfo.d.num_components) / 2;
+                 * sp->cinfo.d.num_components) / 2;
           int iPair;
           for( iPair = 0; iPair < value_pairs; iPair++ )
           {
@@ -1432,7 +1408,7 @@ JPEGDecodeRaw(TIFF* tif, uint8* buf, tmsize_t cc, uint16 s)
             JSAMPLE *in_ptr = (JSAMPLE *) (tmpbuf + iPair * 2);
             out_ptr[0] = (in_ptr[0] & 0xff0) >> 4;
             out_ptr[1] = ((in_ptr[0] & 0xf) << 4)
-                | ((in_ptr[1] & 0xf00) >> 8);
+              | ((in_ptr[1] & 0xf00) >> 8);
             out_ptr[2] = ((in_ptr[1] & 0xff) >> 0);
           }
         }
@@ -1441,12 +1417,9 @@ JPEGDecodeRaw(TIFF* tif, uint8* buf, tmsize_t cc, uint16 s)
 
       sp->scancount ++;
       tif->tif_row += sp->v_sampling;
-/*
-      buf += clumps_per_line*samples_per_clump;
-      cc -= clumps_per_line*samples_per_clump;
-*/
-      buf += sp->bytesperline * sp->v_sampling;
-      cc -= sp->bytesperline * sp->v_sampling;
+
+      buf += sp->bytesperline;
+      cc -= sp->bytesperline;
 
       nrows -= sp->v_sampling;
     } while (nrows > 0);
@@ -1459,7 +1432,7 @@ JPEGDecodeRaw(TIFF* tif, uint8* buf, tmsize_t cc, uint16 s)
 
   /* Close down the decompressor if done. */
   return sp->cinfo.d.output_scanline < sp->cinfo.d.output_height
-      || TIFFjpeg_finish_decompress(sp);
+    || TIFFjpeg_finish_decompress(sp);
 }
 
 
@@ -1724,7 +1697,7 @@ JPEGPreEncode(TIFF* tif, uint16 s)
     } else {
       if ((td->td_photometric == PHOTOMETRIC_MINISWHITE || td->td_photometric == PHOTOMETRIC_MINISBLACK) && td->td_samplesperpixel == 1)
         sp->cinfo.c.in_color_space = JCS_GRAYSCALE;
-      else if (td->td_photometric == PHOTOMETRIC_RGB)
+      else if (td->td_photometric == PHOTOMETRIC_RGB && td->td_samplesperpixel == 3)
         sp->cinfo.c.in_color_space = JCS_RGB;
       else if (td->td_photometric == PHOTOMETRIC_SEPARATED && td->td_samplesperpixel == 4)
         sp->cinfo.c.in_color_space = JCS_CMYK;
@@ -1817,6 +1790,7 @@ JPEGEncode(TIFF* tif, uint8* buf, tmsize_t cc, uint16 s)
         {
             line16_count = (sp->bytesperline * 2) / 3;
             line16 = (short *) _TIFFmalloc(sizeof(short) * line16_count);
+      // FIXME: undiagnosed malloc failure
         }
 
   while (nrows-- > 0) {
@@ -1992,10 +1966,12 @@ JPEGCleanup(TIFF* tif)
   tif->tif_tagmethods.vsetfield = sp->vsetparent;
   tif->tif_tagmethods.printdir = sp->printdir;
 
-  if( sp->cinfo_initialized )
-      TIFFjpeg_destroy(sp);  /* release libjpeg resources */
-  if (sp->jpegtables)    /* tag value */
-    _TIFFfree(sp->jpegtables);
+  if( sp != NULL ) {
+    if( sp->cinfo_initialized )
+        TIFFjpeg_destroy(sp);  /* release libjpeg resources */
+    if (sp->jpegtables)    /* tag value */
+      _TIFFfree(sp->jpegtables);
+  }
   _TIFFfree(tif->tif_data);  /* release local state */
   tif->tif_data = NULL;
 
@@ -2126,13 +2102,15 @@ JPEGPrintDir(TIFF* tif, FILE* fd, long flags)
   JPEGState* sp = JState(tif);
 
   assert(sp != NULL);
-
   (void) flags;
-  if (TIFFFieldSet(tif,FIELD_JPEGTABLES))
-    fprintf(fd, "  JPEG Tables: (%lu bytes)\n",
-      (unsigned long) sp->jpegtables_length);
-  if (sp->printdir)
-    (*sp->printdir)(tif, fd, flags);
+
+        if( sp != NULL ) {
+    if (TIFFFieldSet(tif,FIELD_JPEGTABLES))
+      fprintf(fd, "  JPEG Tables: (%lu bytes)\n",
+        (unsigned long) sp->jpegtables_length);
+    if (sp->printdir)
+      (*sp->printdir)(tif, fd, flags);
+  }
 }
 
 static uint32
@@ -2183,8 +2161,6 @@ JPEGDefaultTileSize(TIFF* tif, uint32* tw, uint32* th)
 static int JPEGInitializeLibJPEG( TIFF * tif, int decompress )
 {
     JPEGState* sp = JState(tif);
-    uint64* byte_counts = NULL;
-    int     data_is_empty = TRUE;
 
     if(sp->cinfo_initialized)
     {
@@ -2198,24 +2174,6 @@ static int JPEGInitializeLibJPEG( TIFF * tif, int decompress )
         sp->cinfo_initialized = 0;
     }
 
-    /*
-     * Do we have tile data already?  Make sure we initialize the
-     * the state in decompressor mode if we have tile data, even if we
-     * are not in read-only file access mode.
-     */
-    if( TIFFIsTiled( tif )
-        && TIFFGetField( tif, TIFFTAG_TILEBYTECOUNTS, &byte_counts )
-        && byte_counts != NULL )
-    {
-        data_is_empty = byte_counts[0] == 0;
-    }
-    if( !TIFFIsTiled( tif )
-        && TIFFGetField( tif, TIFFTAG_STRIPBYTECOUNTS, &byte_counts)
-        && byte_counts != NULL )
-    {
-        data_is_empty = byte_counts[0] == 0;
-    }
-
     /*
      * Initialize libjpeg.
      */
@@ -2325,6 +2283,7 @@ here hopefully is harmless.
 */
             sp->jpegtables_length = SIZE_OF_JPEGTABLES;
             sp->jpegtables = (void *) _TIFFmalloc(sp->jpegtables_length);
+      // FIXME: NULL-deref after malloc failure
       _TIFFmemset(sp->jpegtables, 0, SIZE_OF_JPEGTABLES);
 #undef SIZE_OF_JPEGTABLES
         }
