@@ -1,3 +1,3 @@
-#include <vnl/vnl_matrix.hxx>
+#include "vnl/vnl_matrix.hxx"
 
 VNL_MATRIX_INSTANTIATE(unsigned short);
