@@ -1,5 +1,7 @@
 #include <complex>
-#include <vcl_compiler.h>
+#ifdef _MSC_VER
+#  include "vcl_msvc_warnings.h"
+#endif
 #include <vnl/algo/vnl_svd.hxx>
 
 VNL_SVD_INSTANTIATE(std::complex<float>);
