@@ -292,6 +292,22 @@ test_int()
   TEST("m.update([4],1,1)",
        ((m3 = 4), (m.update(m3, 1, 1)), (m(0, 0) == 0 && m(0, 1) == -2 && m(1, 0) == 2 && m(1, 1) == 4)),
        true);
+
+  { // test operator-() on unsigned values
+    unsigned int vvalues[] = {1, 2, 3, 4};
+    int out_values[] = {-1, -2, -3, -4};
+    const vnl_matrix_fixed<int,2,2> outm( out_values);
+
+    vnl_matrix_fixed<unsigned int,2,2> unsigned_m22(vvalues);
+    const vnl_matrix_fixed<int,2,2> minus_v1 = -unsigned_m22;
+    const vnl_matrix_fixed<int,2,2> minus_v2 = unsigned_m22.operator-();
+    TEST("unsigned_m22.operator-()",
+         (outm(0, 0) == minus_v1(0, 0) && outm(0, 1) == minus_v1(0, 1) && outm(1, 0) == minus_v1(1, 0) &&
+          outm(1, 1) == minus_v1(1, 1)), true);
+    TEST("unsigned_m22.operator-()",
+         (outm(0, 0) == minus_v2(0, 0) && outm(0, 1) == minus_v2(0, 1) && outm(1, 0) == minus_v2(1, 0) &&
+          outm(1, 1) == minus_v2(1, 1)), true);
+  }
 }
 
 static void
